@@ -7,15 +7,12 @@
 
 """
 Unit tests for the NLTK modules.  These tests are intended to ensure
-that changes that we make to NLTK's code don't accidentally introduce
-bugs.
+that source code changes don't accidentally introduce bugs.
+For instructions, please see:
 
-Use doctest_driver.py to run the tests::
+../../web/dev/local_testing.rst
 
-  doctest_driver.py --help
+https://github.com/nltk/nltk/blob/master/web/dev/local_testing.rst
 
-NB. Popular options for NLTK documentation are::
-
-  --ellipsis --normalize_whitespace
 
 """
