@@ -6,7 +6,9 @@ if PY2:
     text_type = unicode
     binary_type = str
     string_types = (str, unicode)
+    unicode = unicode
 else:
     text_type = str
     binary_type = bytes
     string_types = (str,)
+    unicode = str
